<?php

// +---------------------------------------------------------------------------+
// | Things to do Plugin 1.0 for Geeklog - The Ultimate Weblog                 |
// +---------------------------------------------------------------------------+
// | index.php                                                                 |
// |                                                                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | Copyright (C) 2002 by the following authors:                              |
// |                                                                           |
// | Author:                                                                   |
// | Euan McKay                  -    euan@heatherengineering.com              |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett                 -    twillett@users.sourceforge.net           |
// | Blaine Lang                 -    langmail@sympatico.ca                    |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                  -    tony@tonybibbs.com                       |
// |                                                                           |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

require_once('../lib-common.php');

// Check user has rights to access this page
if (!SEC_hasRights('thingstodo.user,thingstodo.admin','OR')) {
    // Someone is trying to illegally access this page
    COM_errorLog("Someone has tried to illegally access the thingstodo page. 
                    User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: $REMOTE_ADDR",1);
    $display = COM_siteHeader();
    $display .= COM_startBlock($LANG_THINGS00['access_denied']);
    $display .= $LANG_THINGS00['access_denied_msg'];
    $display .= COM_endBlock();
    $display .= COM_siteFooter(true);
    echo $display;
    exit;
}

/*
* Function:        thingstodo_listItems()
*
* Takes input:     $sort   (string, optional)    : sort order. Can be: 'start'    = order by start date
*                                                                      'end'      = order by end date
*                                                                      'created'  = order by created date
*                                                                      'priority' = order by priority then start date
*                                                                      'title'    = order alphabetically by title
*                  $direction (string, optional) : direction of sort. Can be 'ASC' or 'DESC'
*                  $author (string, optional)    : restrict list to this author (must be geeklog user id)
*                  $agent  (string, optional)    : restrict list to this agent (must be geeklog user id)
*
* Returns:         formatted HTML             : a list of items from the database to which the user has access rights
*/

function thingstodo_listItems($sort='start', $direction='ASC', $hidestatus='false') {
    global $_TABLES, $_CONF, $_USER, $LANG_THINGS01, $LANG_THINGS_TYPE, $LANG_THINGS_PRIORITY,$TTD_TIME;

    $retval = '';
    $sort = COM_applyFilter($sort);
    $direction = COM_applyFilter($direction);
    $hidestatus = COM_applyFilter($hidestatus);

    if ($hidestatus == "true") {
        $where = " WHERE status='0' " . COM_getPermSQL('AND');
    } else {
        $where = COM_getPermSQL();
    }

    $sql = "SELECT * FROM ".$_TABLES['thingstodo']. $where ." ORDER BY ".$sort." ".$direction;
    $result = DB_query ($sql);
    $T = new Template($_CONF['path_layout'] . 'thingstodo');
    $T->set_file(array('list'=>'list.thtml', 'row'=>'row.thtml'));
    $T->set_var('lang_title', $LANG_THINGS01[2]);
    $T->set_var('lang_description', $LANG_THINGS01[3]);
    $T->set_var('lang_start', $LANG_THINGS01[5]);
    $T->set_var('lang_end', $LANG_THINGS01[6]);
    $T->set_var('lang_topic', $LANG_THINGS01[37]);
    $T->set_var('lang_type', $LANG_THINGS01[7]);
    $T->set_var('lang_priority', $LANG_THINGS01[8]);
    $T->set_var('lang_author', $LANG_THINGS01[12]);
    $T->set_var('lang_agent', $LANG_THINGS01[13]);
    $T->set_var('lang_status', $LANG_THINGS01[20]);
    $T->set_var('lang_edit', $LANG_THINGS01[16]);
    $T->set_var('lang_clone', $LANG_THINGS01[17]);
    $T->set_var('lang_complete', $LANG_THINGS01[18]);
    $T->set_var('lang_delete', $LANG_THINGS01[19]);
    $T->set_var('hide_status_link', 'hidestatus='.$hidestatus);
    $nrows = DB_numRows($result);
    if ($nrows == 0) {
        $T->set_var('things',$LANG_THINGS01[26]);
    } else {
        for ($i = 0; $i < $nrows; $i++) {
            $A = DB_fetchArray($result);
            $T->set_var('id', $A['id']);
            $T->set_var('title', stripslashes($A['title']));
            $T->set_var('description', substr(stripslashes($A['description']),0,20));
            $T->set_var('start', strftime($TTD_TIME['date'],$A['start']));
            $T->set_var('end', strftime($TTD_TIME['date'],$A['end']));
            $T->set_var('topic', DB_getItem($_TABLES['topics'],'topic',"tid='{$A['tid']}'"));
            $T->set_var('type', $LANG_THINGS_TYPE[$A['type']]);
            $T->set_var('priority', $LANG_THINGS_PRIORITY[$A['priority']]);
            $T->set_var('ttd_priority', "ttd_".$A['priority']);
            if ($A['status'] == '0') {
                $T->set_var('status', "incomplete");
                $T->set_var('switch', "1");
                $T->set_var('switch_complete', "setcomplete");
            } else {
                $T->set_var('status', "completed");
                $T->set_var('switch', "0");
                $T->set_var('switch_complete', "setincomplete");
            }
            $T->set_var('layout_url',$_CONF['layout_url']);
            $T->parse('things', 'row', true);
        }
    }
    $T->set_var('site_url',$_CONF['site_url']);
    $T->set_var('layout_url',$_CONF['layout_url']);
    $T->parse('output','list');
    $retval = $T->finish($T->get_var('output'));

    return $retval;
}


/*
* Function:        thingstodo_editItem()
*
* Takes input:     $item  (string, optional)  : id number of item to be edited
*                  $clone (Boolean, optional) : if true, the supplied $item will be cloned
*
* Returns:         formatted HTML             : a form for editing an item, with fields set as required
*/

function thingstodo_editItem($item='', $clone = false) {
    global $_TABLES, $_CONF, $_USER, $LANG_THINGS01, $LANG_THINGS_TYPE, $LANG_THINGS_PRIORITY;
    global $THINGS_DEFAULTS, $LANG_ACCESS, $LANG24, $TTD_TIME;
    $retval = '';
    $item = COM_applyFilter($item);
    $clone = COM_applyFilter($clone);
    $existing = false;

    $result = DB_query("SELECT * FROM {$_TABLES['thingstodo']} WHERE id = '{$item}'");

    if (DB_numRows ($result) > 0) {     // existing item in DB
        $A = DB_fetchArray($result);
        $existing = true;
    }
    $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
                             $A['perm_group'], $A['perm_members'], $A['perm_anon']);

    if (($access < 3) && ($item > 0)) {
        return $LANG_THINGS01[27];
    } else {

        $agent_options = '';
        $result = DB_query("SELECT uid,username FROM " . $_TABLES['users']);
        $nrows = DB_numRows($result);
        $G = DB_fetchArray($result);               // first should be anonymous, so skip them
        for ($i = 1; $i < $nrows; $i++) {
            $G = DB_fetchArray($result);
            $agent_options .= '<option value="' . $G['uid'] . '">' . $G['username'] . '</option>';
        }

        $type_options = '';
        foreach ($LANG_THINGS_TYPE as $k => $v) {
            $type_options .= '<option value="' . $k . '">' . $v . '</option>';
        }

        $priority_options = '';
        foreach ($LANG_THINGS_PRIORITY as $k => $v) {
            $priority_options .= '<option value="' . $k . '">' . $v . '</option>';
        }

        $T = new Template($_CONF['path_layout'] . 'thingstodo');
        $T->set_file('form','edit.thtml');
        $T->set_var('site_url', $_CONF['site_url']);
        $T->set_var('lang_title', $LANG_THINGS01[2]);
        $T->set_var('lang_description', $LANG_THINGS01[3]);
        $T->set_var('lang_created', $LANG_THINGS01[4]);
        $T->set_var('lang_modified', $LANG_THINGS01[38]);
        $T->set_var('lang_start', $LANG_THINGS01[5]);
        $T->set_var('lang_end', $LANG_THINGS01[6]);
        $T->set_var('lang_type', $LANG_THINGS01[7]);
        $T->set_var('lang_priority', $LANG_THINGS01[8]);
        $T->set_var('lang_owner', $LANG_THINGS01[12]);
        $T->set_var('lang_agent', $LANG_THINGS01[13]);
        $T->set_var('save', $LANG_THINGS01[9]);
        $T->set_var('cancel', $LANG_THINGS01[10]);
        $T->set_var('lang_accessrights',$LANG_ACCESS['accessrights']);
        $T->set_var('lang_group', $LANG_ACCESS['group']);
        $T->set_var('lang_permissions', $LANG_ACCESS['permissions']);
        $T->set_var('lang_perm_key', $LANG_ACCESS['permissionskey']);
        $T->set_var('permissions_msg', $LANG_ACCESS['permmsg']);
        $T->set_var('lang_topic', $LANG24[14]);

        if ($existing == true) {     // existing item in DB
            $T->set_var('title', stripslashes($A['title']));
            $T->set_var('description', stripslashes($A['description']));
            $T->set_var('created', strftime($TTD_TIME['full'],$A['created']));
            $T->set_var('modified', strftime($TTD_TIME['full'],$A['modified']));
            $T->set_var('start', strftime($TTD_TIME['noday'],$A['start']));
            $T->set_var('end', strftime($TTD_TIME['noday'],$A['end']));
            $type_options = str_replace('value="'.$A['type'].'">','value="'.$A['type'].'" selected="selected">',$type_options);
            $priority_options = str_replace('value="'.$A['priority'].'">','value="'.$A['priority'].'" selected="selected">',$priority_options);
            $agent_options = str_replace('value="'.$A['agent'].'">','value="'.$A['agent'].'" selected="selected">',$agent_options);

            if ($clone) {                                                   // $clone = true so clone an item
                $T->set_var('head', $LANG_THINGS01[15]);
                $T->set_var('id', '');
                $A['owner_id'] = $_USER['uid'];
            } else {                                                        // $clone = false so edit an item
                $T->set_var('head', $LANG_THINGS01[14]);
                $T->set_var('id', $A['id']);
            }

        } else {                            // no item so new item, no topic set yet for permissions
            $A['owner_id'] = $_USER['uid'];
            $A['group_id'] = DB_getItem ($_TABLES['groups'], 'grp_id', "grp_name = 'Things to do Admin'");
            $A['perm_owner'] = 3;
            $A['perm_group'] = 3;
            $A['perm_members'] = 2;
            $A['perm_anon'] = 2;
            $T->set_var('head', $LANG_THINGS01[1]);
            $T->set_var('id', '');
            $type_options = str_replace('value="'.$A['type'].'">','value="'.$THINGS_DEFAULTS['type'].'" selected="selected">',$type_options);
            $priority_options = str_replace('value="'.$A['type'].'">','value="'.$THINGS_DEFAULTS['priority'].'" selected="selected">',$priority_options);
        }

        $T->set_var('agent', $agent_options);
        $T->set_var('priority', $priority_options);
        $T->set_var('type', $type_options);
        $T->set_var('owner_username', DB_getItem ($_TABLES['users'], 'username', "uid = {$A['owner_id']}"));
        $T->set_var('owner_id', $A['owner_id']);
        $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
                                 $A['perm_group'], $A['perm_members'], $A['perm_anon']);

        $usergroups = SEC_getUserGroups();
        $groupdd = '';
        if ($access == 3) {
            $groupdd .= '<select name="group_id">';
            for ($i = 0; $i < count($usergroups); $i++) {
                $groupdd .= '<option value="' . $usergroups[key($usergroups)] . '"';
                if ($A['group_id'] == $usergroups[key($usergroups)]) {
                    $groupdd .= ' selected="selected"';
                }
                $groupdd .= '>' . key($usergroups) . '</option>';
                next($usergroups);
            }
            $groupdd .= '</select>';
        } else {
            // they can't set the group then
            $groupdd .= DB_getItem ($_TABLES['groups'], 'grp_name', "grp_id = {$A['group_id']}");
            $groupdd .= '<input type="hidden" name="group_id" value="' . $A['group_id'] . '">';
        }

        $T->set_var('group_dropdown', $groupdd);
        $T->set_var('permissions_editor', 
                    SEC_getPermissionsHTML($A['perm_owner'],$A['perm_group'],$A['perm_members'],$A['perm_anon']));

        if (empty ($A['tid'])) {
            $A['tid'] = DB_getItem ($_TABLES['topics'], 'tid', 'is_default = 1' . COM_getPermSQL ('AND'));
        }
        $T->set_var ('topic_options', COM_topicList ('tid,topic', $A['tid']));
        $T->parse('output','form');
        $retval = $T->finish($T->get_var('output'));
    }
    return $retval;
}


/*
* Function:        thingstodo_viewItem()
*
* Takes input:     $item  (string, required)  : id number of item to be edited
*
* Returns:         formatted HTML             : a page for viewing an item
*/

function thingstodo_viewItem($item) {
    global $_TABLES, $_CONF, $LANG_THINGS01, $LANG_THINGS_TYPE, $LANG_THINGS_PRIORITY, $TTD_TIME;
    $retval = '';
    $item = COM_applyFilter($item);

    $T = new Template($_CONF['path_layout'] . 'thingstodo');
    $T->set_file('form','view.thtml');
    $T->set_var('lang_title', $LANG_THINGS01[2]);
    $T->set_var('lang_description', $LANG_THINGS01[3]);
    $T->set_var('lang_created', $LANG_THINGS01[4]);
    $T->set_var('lang_modified', $LANG_THINGS01[38]);
    $T->set_var('lang_start', $LANG_THINGS01[5]);
    $T->set_var('lang_end', $LANG_THINGS01[6]);
    $T->set_var('lang_topic', $LANG_THINGS01[37]);
    $T->set_var('lang_type', $LANG_THINGS01[7]);
    $T->set_var('lang_status', $LANG_THINGS01[20]);
    $T->set_var('lang_priority', $LANG_THINGS01[8]);
    $T->set_var('lang_author', $LANG_THINGS01[12]);
    $T->set_var('lang_agent', $LANG_THINGS01[13]);
    $T->set_var('layout_url', $_CONF['layout_url']);
    $T->set_var('site_url', $_CONF['site_url']);

    if ((!$item == '0') && (!$item == '') && (isset($item))) {      // we definitely have an id number
        $result = DB_query ("SELECT * FROM {$_TABLES['thingstodo']} WHERE id ='{$item}'");
        $A = DB_fetchArray($result);
        $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
                                 $A['perm_group'], $A['perm_members'], $A['perm_anon']);

        if (($access < 2) || (SEC_hasTopicAccess ($A['tid']) < 2)) {
            return $LANG_THINGS01[27];                              // this is not their item
        } else {
            if ($A['status'] == '1') {
                $T->set_var('switch_complete', 'setincomplete');
                $T->set_var('switch', '0');
            } else {
                $T->set_var('switch_complete', 'setcomplete');
                $T->set_var('switch', '1');
            }
            $T->set_var('head', $LANG_THINGS01[21]);
            $T->set_var('id', $A['id']);
            $T->set_var('title', stripslashes($A['title']));
            $T->set_var('description', stripslashes($A['description']));
            $T->set_var('created', strftime($TTD_TIME['full'],$A['created']));
            $T->set_var('modified', strftime($TTD_TIME['full'],$A['modified']));
            $T->set_var('start', strftime($TTD_TIME['full'],$A['start']));
            $T->set_var('end', strftime($TTD_TIME['full'],$A['end']));
            $T->set_var('topic', DB_getItem($_TABLES['topics'],'topic',"tid='{$A['tid']}'"));
            $T->set_var('type', $LANG_THINGS_TYPE[$A['type']]);
            $T->set_var('status', $A['status']);
            $T->set_var('priority', $LANG_THINGS_PRIORITY[$A['priority']]);
            $T->set_var('author', $A['owner_id']);
            $T->set_var('agent', $A['agent']);
            $T->set_var('author_name', DB_getItem($_TABLES['users'], "username", "uid = ".$A['owner_id']));
            $T->set_var('agent_name', DB_getItem($_TABLES['users'], "username", "uid = ".$A['agent']));
        }

    } else {                                                        // no id, so an error
            return $LANG_THINGS01[28];
    }

    $T->parse('output','form');
    $retval = $T->finish($T->get_var('output'));
    return $retval;
}


/*
* Function:        thingstodo_completeItem()
*
* Takes input:     $item (string, required)   : id of item to be completed
*
* Returns:         text                       : a message describing the result of the request
*/

function thingstodo_completeItem($item,$switch) {
    global $_TABLES, $_CONF, $_USER, $LANG_THINGS01;
    $retval = '';
    if ($switch !=  '1') {
        $switch = 0;
    }
    $test = DB_query("SELECT * FROM {$_TABLES['thingstodo']} WHERE id='{$item}'");
    $nrows = DB_numRows($test);
    if (($nrows == 0) || ($item == '') || ($item < '1') ) {
        $retval = sprintf($LANG_THINGS01[34],$item);
    } else {                                                        // existing item, so update item in DB
        $sql = "UPDATE {$_TABLES['thingstodo']} SET status='{$switch}' WHERE id='{$item}'";
        DB_query($sql);
        if (DB_error()) {
            $retval = $LANG_THINGS01[25];
        } else {
            $retval = $LANG_THINGS01[29];
        }
    }
    return $retval;
}


/*
* Function:        thingstodo_saveItem()
*
* Takes input:     $item (array, required)    : array of data to be saved
*
* Returns:         text                       : a message describing the result of the request
*/

function thingstodo_saveItem($item) {
    global $_TABLES, $_CONF, $_USER, $LANG_THINGS01, $MESSAGE;
    list($perm_owner,$perm_group,$perm_members,$perm_anon) = 
         SEC_getPermissionValues($item['perm_owner'],$item['perm_group'],$item['perm_members'],$item['perm_anon']);

    $access = 0;
    if (DB_count ($_TABLES['thingstodo'], 'id', $item['id']) > 0) {
        $result = DB_query ("SELECT owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['thingstodo']} WHERE id = '{$item['id']}'");
        $A = DB_fetchArray ($result);
        $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
                                 $A['perm_group'], $A['perm_members'], $A['perm_anon']);
    } else {
        $access = SEC_hasAccess ($item['owner_id'], $item['group_id'], $perm_owner,
                                 $perm_group, $perm_members, $perm_anon);
    }

    if (($access < 3) || (SEC_hasTopicAccess ($item['tid']) < 2)) {
        $display .= COM_siteHeader ('menu');
        $display .= COM_startBlock ($MESSAGE[30], '', COM_getBlockTemplate ('_msg_block', 'header'));
        $display .= $MESSAGE[31];
        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
        $display .= COM_siteFooter ();
        COM_accessLog("User {$_USER['username']} tried to illegally submit or edit thingstodo item {$item['id']}.");
        echo $display;
        exit;
    } else {

        $retval = '';
        $title = addslashes(COM_applyFilter($item['title']));
        $description = addslashes(COM_applyFilter($item['description']));
        $type = COM_applyFilter($item['type']);
        $priority = COM_applyFilter($item['priority']);
        $agent = COM_applyFilter($item['agent']);
        $tid = COM_applyFilter($item['tid']);
        $modified = time();
        $start = strtotime(COM_applyFilter($item['start']));
        $end = strtotime(COM_applyFilter($item['end']));

        if (($item['id'] == '') || ($item['id'] < '1')) {          // no id means that this is a new item, so insert into DB
            $sql = "INSERT INTO {$_TABLES['thingstodo']} 
                    (type, start, end, title, description, created, modified, agent, priority, tid,
                     owner_id, group_id, perm_owner, perm_group, perm_members, perm_anon) 
                    VALUES 
                    ('{$type}','{$start}','{$end}','{$title}','{$description}',
                    '{$modified}','{$modified}','{$agent}','{$priority}','{$tid}',
                    '{$item['owner_id']}','{$item['group_id']}','{$perm_owner}','{$perm_group}','{$perm_members}','{$perm_anon}'
                    )";
        } else {                                                   // existing item, so update item in DB
            $sql = "UPDATE {$_TABLES['thingstodo']} 
                    SET 
                    type='{$type}',start='{$start}',end='{$end}',modified='{$modified}',
                    title='{$title}',description='{$description}',priority='{$priority}',agent='{$agent}',tid='{$tid}',
                    owner_id='{$item['owner_id']}',group_id='{$item['group_id']}',
                    perm_owner='{$perm_owner}',perm_group='{$perm_group}',
                    perm_members='{$perm_members}',perm_anon='{$perm_anon}'
                    WHERE id='{$item['id']}'";
        }

        DB_query($sql);
        if (DB_error()) {
            $retval = $LANG_THINGS01[25];
        } else {
            $retval = $LANG_THINGS01[30];
        }
        return $retval;
    }
}


/*
* Function:        thingstodo_deleteItem()
*
* Takes input:     $item (string, required)   : id number of item to be deleted
*
* Returns:         text                       : a message describing the result of the request
*/

function thingstodo_deleteItem($item) {
    global $_TABLES, $_CONF, $_USER, $LANG_THINGS01;
    $retval = '';

    $result = DB_query ("SELECT * FROM {$_TABLES['thingstodo']} WHERE id = '$item'");
    $A = DB_fetchArray ($result);
    $access = SEC_hasAccess ($A['owner_id'], $A['group_id'], $A['perm_owner'],
                             $A['perm_group'], $A['perm_members'], $A['perm_anon']);
    $access = min ($access, SEC_hasTopicAccess ($A['id']));

    if ($access < 3) {
        COM_accessLog ("User {$_USER['username']} tried to illegally delete thingstodo item {$item}.");
        $retval = "User {$_USER['username']} illegally tried to delete item  {$item}";
    } else {
        DB_delete ($_TABLES['thingstodo'], 'id', $item);
    }

    return $retval;
}


/************************************************************************/
/*                                                                       /
/* Main                                                                  /
/*                                                                       /
/*************************************************************************/

if ((isset($HTTP_POST_VARS['mode'])) || (isset($HTTP_POST_VARS['sort']))) {
    $vars = $HTTP_POST_VARS;
} else {
    $vars = $HTTP_GET_VARS;
}
$msg = '';
$mode    = COM_applyFilter($vars['mode']);
$id = COM_applyFilter($vars['id']);
$switch = COM_applyFilter($vars['switch']);

if (isset($vars['sort'])) {
    $sort    = COM_applyFilter($vars['sort']);
} else {
    $sort = 'start';
}

if (isset($vars['direction'])) {
    $direction    = COM_applyFilter($vars['direction']);
} else {
    $direction = 'asc';
}

if (isset($vars['hidestatus'])) {
    $hidestatus    = COM_applyFilter($vars['hidestatus']);
} else {
    $hidestatus = 'false';
}

if ($mode == 'deleteitem') {                                            // delete an item
    if (!isset ($id) || empty ($id) || ($id == 0)) {                    // check for an item id
        $msg = sprintf($LANG_THINGS01[33],$id);                         // no id so set message here
    } else {
        $msg = thingstodo_deleteItem ($id);                             // OK so delete item
        $display = thingstodo_listItems();                              // get items
    }

} else if ($mode == $LANG_THINGS01[9]) {                                // save an item
    $msg = thingstodo_saveItem ($vars);      // OK so save item
    $display = thingstodo_listItems();                                  // get items

} else if ($mode == 'completeitem') {                                   // complete an existing item
    if (!isset ($id) || empty ($id) || ($id == 0)) {                    // check for an item id
        $msg = sprintf($LANG_THINGS01[34],$id);                         // no id so set message here
    } else {
        $msg = thingstodo_completeItem ($id,$switch);                   // OK so complete item
        $display = thingstodo_listItems();                              // get items
    }

} else if ($mode == 'cloneitem') {                                      // clone an existing item
    if (!isset ($id) || empty ($id) || ($id == 0)) {                    // check for an item id
        $msg = sprintf($LANG_THINGS01[35],$id);                         // no id so set message here
    } else {
        $display = thingstodo_editItem ($id,true);                      // OK so show edit form with data
    }

} else if ($mode == 'edititem') {                                       // edit an existing item
    if (!isset ($id) || empty ($id) || ($id == 0)) {                    // check for an item id
        $msg = sprintf($LANG_THINGS01[36],$id);                         // no id so set message here
    } else {
        $display = thingstodo_editItem ($id);                           // OK so show populated item
    }

} else if ($mode == 'newitem') {                                        // create a new item
    $display = thingstodo_editItem ();                                  // Show a blank form

} else if ($mode == 'viewitem') {                                       // view an item
    $display = thingstodo_viewItem ($id);                               // Show a populated page

} else {                                                                // 'cancel' or no mode at all so list items
    $display = thingstodo_listItems($sort,$direction,$hidestatus);      // get items
}


// Display page

$page = COM_siteHeader();
if (isset ($msg)) {
    $page .= thingstodo_showMessage($msg);
}

$P = new Template($_CONF['path_layout'] . 'thingstodo');
$P->set_file('page','index.thtml');
$P->set_var('header', "Things to do today plugin");
$P->set_var('listall', "List all");
$P->set_var('newitem', "New item");
$P->set_var('site_url', $_CONF['site_url']);
$P->set_var('layout_url', $_CONF['layout_url']);
$P->set_var('edit', $LANG_THINGS01[16]);
$P->set_var('clone', $LANG_THINGS01[17]);
$P->set_var('setcomplete', $LANG_THINGS01[18]);
$P->set_var('setincomplete', $LANG_THINGS01[24]);
$P->set_var('delete', $LANG_THINGS01[19]);
if ($hidestatus == 'true') {
    $P->set_var('hide_status_lang', $LANG_THINGS01['23']);
    $P->set_var('hide_status_link', 'hidestatus=false');
} else {
    $P->set_var('hide_status_lang', $LANG_THINGS01['22']);
    $P->set_var('hide_status_link', 'hidestatus=true');
}
$P->set_var('sort_link', 'sort='.$sort.'&direction='.$direction.'&');
$P->set_var('pagecontent', $display);
$P->parse('output','page');
$page .= $P->finish($P->get_var('output'));

$page .= COM_siteFooter();

echo $page;

?>